@@ -44,17 +44,10 @@
 #include <KLocalizedString>
 
 #include <kauth_version.h>
-#if KAUTH_VERSION >= QT_VERSION_CHECK(5, 92, 0)
 #include <KAuth/Action>
 #include <KAuth/ExecuteJob>
-#else
-#include <KAuthAction>
-#include <KAuthExecuteJob>
-#endif
 
-K_PLUGIN_FACTORY(PowerDevilGeneralKCMFactory,
-                 registerPlugin<GeneralPage>();
-                )
+K_PLUGIN_CLASS_WITH_JSON(GeneralPage, "kcm_powerdevilglobalconfig.json")
 
 GeneralPage::GeneralPage(QWidget *parent, const QVariantList &args)
         : KCModule(parent, args)
